#define OPENEXR_IMF_HAVE_DARWIN 1
#define OPENEXR_IMF_HAVE_COMPLETE_IOMANIP 1
#include <string.h>
#define OPENEXR_IMF_INTERNAL_NAMESPACE_CUSTOM 0
#define OPENEXR_IMF_NAMESPACE Imf
#define OPENEXR_IMF_INTERNAL_NAMESPACE Imf

#define OPENEXR_VERSION_STRING "2.2.0"
#define OPENEXR_PACKAGE_STRING "OpenEXR 2.2.0"

#define OPENEXR_VERSION_MAJOR 2
#define OPENEXR_VERSION_MINOR 2
#define OPENEXR_VERSION_PATCH 0

// Version as a single hex number, e.g. 0x01000300 == 1.0.3
#define OPENEXR_VERSION_HEX ((OPENEXR_VERSION_MAJOR << 24) | \
                             (OPENEXR_VERSION_MINOR << 16) | \
                             (OPENEXR_VERSION_PATCH <<  8))

#ifndef __arm64__
#define OPENEXR_IMF_HAVE_GCC_INLINE_ASM_AVX 1
#endif
#define OPENEXR_IMF_HAVE_SYSCONF_NPROCESSORS_ONLN 1
